@@ -5,7 +5,7 @@
 # Alias for Lemonldap::NG::Handler::SharedConf
 package Lemonldap::NG::Handler;
 
-our $VERSION = "0.9";
+our $VERSION = '1.0.1';
 use Lemonldap::NG::Handler::SharedConf;
 use base qw(Lemonldap::NG::Handler::SharedConf);
 
@@ -15,6 +15,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Lemonldap::NG::Handler - The Apache protection module part of
@@ -108,7 +110,7 @@ but B<not with mod_perl 1.99>.
 
 =head3 B<Authentication>
 
-If a user isn't authenticated and attemps to connect to an area protected by a
+If a user isn't authenticated and attempts to connect to an area protected by a
 Lemonldap::NG compatible handler, he is redirected to a portal. The portal
 authenticates user with a ldap bind by default, but you can also use another
 authentication sheme like using x509 user certificates (see
@@ -196,7 +198,7 @@ on a protected area.
 
 =back
 
-It is also recommanded to use the C<groups> mechanism to avoid having to
+It is also recommended to use the C<groups> mechanism to avoid having to
 evaluate a long expression at each HTTP request:
 
   locationRules => {
@@ -218,7 +220,7 @@ C<groups> parameter. Perl expressions has to be enclosed with C<{}>:
 
 =back
 
-It is also recommanded to use Perl expressions to avoid requiering the LDAP
+It is also recommended to use Perl expressions to avoid requiering the LDAP
 server more than 2 times per authentication.
 
 =head3 B<Accounting>
@@ -247,7 +249,7 @@ virtual host:
 
 =over
 
-=item * B<keys> are the names of the choosen headers
+=item * B<keys> are the names of the chosen headers
 
 =item * B<values> are Perl expressions where you can use user datas stored in
 the global store by calling them C<$E<lt>varnameE<gt>>.
@@ -351,7 +353,7 @@ download a mod_perl2 backport.
 
 L<Lemonldap::NG::Handler::SharedConf>,
 L<Lemonldap::NG::Portal>, L<Lemonldap::NG::Manager>,
-L<http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation>
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -360,7 +362,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -369,15 +371,10 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-Lemonldap was originaly written by Eric German who decided to publish him in
-2003 under the terms of the GNU General Public License version 2.
-Lemonldap::NG is a complete rewrite of Lemonldap and is able to have different
-policies in a same Apache virtual host.
-
 =cut
