@@ -5,7 +5,7 @@
 # Alias for Lemonldap::NG::SharedConf
 package Lemonldap::NG::Portal;
 
-our $VERSION = "0.86";
+our $VERSION = '1.0.1';
 use Lemonldap::NG::Portal::SharedConf;
 use base 'Lemonldap::NG::Portal::SharedConf';
 
@@ -15,6 +15,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Lemonldap::NG::Portal - The authentication portal part of Lemonldap::NG Web-SSO
@@ -50,7 +52,7 @@ system.
   }
   else {
       # Write here the html form used to authenticate with CGI methods.
-      # $portal->error returns the error message if authentification failed
+      # $portal->error returns the error message if authentication failed
       # You can force the language in error like this :
       #   print $portal->error('fr')
       # Warning: by defaut, input names are "user" and "password"
@@ -75,7 +77,7 @@ SOAP mode authentication (client) :
   
   my $soap =
     SOAP::Lite->proxy('http://auth.example.com/')
-    ->uri('urn:/Lemonldap::NG::Common::::CGI::SOAPService');
+    ->uri('urn:/Lemonldap::NG::Common::CGI::SOAPService');
   my $r = $soap->getCookies( 'user', 'password' );
   
   # Catch SOAP errors
@@ -112,7 +114,7 @@ and use all L<CGI> features.
 
 =head3 B<Authentication>
 
-If a user isn't authenticated and attemps to connect to an area protected by a
+If a user isn't authenticated and attempts to connect to an area protected by a
 Lemonldap::NG compatible handler, he is redirected to a portal. The portal
 authenticates user with a ldap bind by default, but you can also use another
 authentication sheme like using x509 user certificates (see
@@ -143,7 +145,7 @@ authorization (see C<exportedHeaders> parameter in L<Lemonldap::NG::Portal>
 documentation),
 
 =item * create Perl expression to define user groups (using ldap attributes):
-optionnal, this mechanism is available with Lemonldap::NG::*::SharedConf
+optional, this mechanism is available with Lemonldap::NG::*::SharedConf
 modules,
 
 =item * create an array foreach virtual host associating URI regular
@@ -201,7 +203,7 @@ You have to be careful when choosing your expressions:
 
 =back
 
-It is also recommanded to use the C<groups> mechanism to avoid having to
+It is also recommended to use the C<groups> mechanism to avoid having to
 evaluate a long expression at each HTTP request:
 
   locationRules => {
@@ -223,7 +225,7 @@ mixed expressions. Perl expressions has to be enclosed with C<{}>:
 
 =back
 
-It is also recommanded to use Perl expressions to avoid requiering the LDAP
+It is also recommended to use Perl expressions to avoid requiering the LDAP
 server more than 2 times per authentication.
 
 =head3 B<Accounting>
@@ -251,7 +253,7 @@ database). This parameters contains an associative array:
 
 =over
 
-=item * B<keys> are the names of the choosen headers
+=item * B<keys> are the names of the chosen headers
 
 =item * B<values> are perl expressions where you can use user datas stored in
 the global store by calling them C<$E<lt>varnameE<gt>>.
@@ -359,7 +361,7 @@ default).
 only on your server.
 
 =item * globalStorage : required: L<Apache::Session> library to used to store
-session informations.
+session information.
 
 =item * globalStorageOptions : parameters to bind to L<Apache::Session> module
 
@@ -372,7 +374,7 @@ be set to:
 
 =over
 
-=item * ldap : authentification is done by LDAP bind
+=item * ldap : authentication is done by LDAP bind
 
 =item * SSL : the portal reads SSL variables issued from Apache SSL
 authentication. See L<Lemonldap::NG::Portal::AuthSSL> for more.
@@ -404,7 +406,7 @@ describe how to find configuration generated by L<Lemonldap::NG::Manager>. See
 L<Lemonldap::NG::Common::Conf> for more
 
 =item * caPath, caFile : if you use ldap+tls you can overwrite cafile or capath
-options with those parameters. This is usefull if you use a shared
+options with those parameters. This is useful if you use a shared
 configuration.
 
 =item * ldapPpolicyControl : set it to 1 if you want to use LDAP Password
@@ -480,18 +482,13 @@ Liberty-Alliance mechanisms to authenticate users
 to read portal configuration from a central database. It inherits from
 L<Lemonldap::NG::Portal::Simple>. It's the more used module.
 
-=item * L<Lemonldap::NG::Portal::CDA>: this module inherits from
-L<Lemonldap::NG::Portal::SharedConf> and provides the capability to use
-handlers in different domains that the portal itself. See
-L<Lemonldap::NG::Portal::CDA> for more.
-
 =back
 
 =head1 SEE ALSO
 
 L<Lemonldap::NG::Portal::SharedConf>, L<Lemonldap::NG::Portal::Simple>
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Manager>,
-http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
+L<http://lemonldap-ng.org/>
 
 =head1 AUTHOR
 
@@ -500,7 +497,7 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://forge.objectweb.org/tracker/?group_id=274>
+L<http://jira.ow2.org>
 
 =head1 DOWNLOAD
 
@@ -509,15 +506,10 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
+Copyright (C) 2005, 2007, 2010 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-Lemonldap::NG was originaly written by Eric German who decided to publish him in
-2003 under the terms of the GNU General Public License version 2.
-Lemonldap::NG is a complete rewrite of Lemonldap and is able to have different
-policies in a same Apache virtual host.
-
 =cut
